import os

os.chdir("tex")

if "rules.tex" in os.popen("kpsewhich rules.tex").read():
	pass
#	os.remove("rules.tex")
else:
	print("rules.tex not installed in TeX directory")
	raise SystemExit
if "properties.tex" in os.popen("kpsewhich properties.tex").read():
	pass
#	os.remove("properties.tex")
else:
	print("properties.tex not installed in TeX directory")
	raise SystemExit
if "common.tex" in os.popen("kpsewhich common.tex").read():
	pass
#	os.remove("common.tex")
else:
	print("common.tex not installed in TeX directory")
	raise SystemExit
if os.name == 'nt':
	os.system("parse.py geom")
	os.system("parse.py indnum")
	os.system("parse.py divides")
	os.system("check.py geom .")
	os.system("check.py indnum .")
	os.system("check.py divides .")
else:
	os.system("parse geom")
	os.system("parse indnum")
	os.system("parse divides")
	os.system("check geom .")
	os.system("check indnum .")
	os.system("check divides .")
